import { Component, OnInit, ViewChild, ViewEncapsulation } from '@angular/core';
import { extend } from '@syncfusion/ej2-base';
import {
  EventSettingsModel, DayService, WeekService, WorkWeekService, MonthService,
  AgendaService, ScheduleComponent, TimeScaleModel, ResizeService, DragAndDropService, GroupModel
} from '@syncfusion/ej2-angular-schedule';
import { MatDialogConfig, MatDialog } from '@angular/material';
import { loadCldr, L10n, setCulture } from '@syncfusion/ej2-base';

const MAXHEIGHT: Number = 750;

loadCldr(
  require('../../../node_modules/cldr-data/supplemental/numberingSystems.json'),
  require('../../../node_modules/cldr-data/main/fr-CH/ca-gregorian.json'),
  require('../../../node_modules/cldr-data/main/fr-CH/numbers.json'),
  require('../../../node_modules/cldr-data/main/fr-CH/timeZoneNames.json'));
L10n.load({
  'fr-CH': {
    'schedule': {
      'day': 'journée',
      'week': 'La semaine',
      'workWeek': 'Semaine de travail',
      'month': 'Mois',
      'agenda': 'Ordre du jour',
      'weekAgenda': 'Agenda de la semaine',
      'workWeekAgenda': 'Agenda de la semaine de travail',
      'monthAgenda': 'Agenda du mois',
      'today': 'Aujourd\'hui',
      'noEvents': 'Pas d\'événements',
      'emptyContainer': 'Il n\'y a pas d\'événements programmés ce jour-là.',
      'allDay': 'Toute la journée',
      'start': 'Début',
      'end': 'Fin',
      'more': 'plus',
      'close': 'Fermer',
      'cancel': 'Annuler',
      'noTitle': '(Pas de titre)',
      'delete': 'Effacer',
      'deleteEvent': 'Supprimer l\'événement',
      'deleteMultipleEvent': 'Supprimer plusieurs événements',
      'selectedItems': 'Articles sélectionnés',
      'deleteSeries': 'Supprimer la série',
      'edit': 'modifier',
      'editSeries': 'Editer une série',
      'editEvent': 'Editer un événement',
      'createEvent': 'Créer',
      'subject': 'Assujettir',
      'addTitle': 'Ajouter un titre',
      'moreDetails': 'Plus de détails',
      'save': 'sauvegarder',
      'editContent': 'Voulez-vous éditer uniquement cet événement ou une série entière?',
      'deleteRecurrenceContent': 'Voulez-vous supprimer uniquement cet événement ou une série entière?',
      'deleteContent': 'Êtes-vous sûr de vouloir supprimer cet événement?',
      'deleteMultipleContent': 'Êtes-vous sûr de vouloir supprimer les événements sélectionnés?',
      'newEvent': 'Nouvel évènement',
      'title': 'Titre',
      'location': 'Emplacement',
      'description': 'La description',
      'timezone': 'Fuseau horaire',
      'startTimezone': 'Démarrer le fuseau horaire',
      'endTimezone': 'Fin du fuseau horaire',
      'repeat': 'Répéter',
      'saveButton': 'sauvegarder',
      'cancelButton': 'Annuler',
      'deleteButton': 'Effacer',
      'recurrence': 'Récurrence',
      'wrongPattern': 'Le modèle de récurrence n\'est pas valide.',
      'seriesChangeAlert': 'Les modifications apportées à des instances spécifiques de cette série seront annulées et ces événements correspondront à nouveau à la série.',
      'createError': 'La durée de l\'événement doit être plus courte que sa fréquence.',
      'recurrenceDateValidation': 'Certains mois ont moins que la date sélectionnée. Pour ces mois, l\'occurrence tombera sur la dernière date du mois.',
      'sameDayAlert': 'Deux occurrences du même événement ne peuvent pas se produire le même jour.',
      'editRecurrence': 'Modifier la périodicité',
      'repeats': 'Répétitions',
      'alert': 'Alerte',
      'startEndError': 'La date de fin sélectionnée est antérieure à la date de début.',
      'invalidDateError': 'La date entrée est invalide.',
      'ok': 'D\'accord',
      'occurrence': 'Occurrence',
      'series': 'Séries',
      'previous': 'précédent',
      'next': 'Suivant',
      'timelineDay': 'Jour de la chronologie',
      'timelineWeek': 'Semaine de la chronologie',
      'timelineWorkWeek': 'Semaine de travail',
      'timelineMonth': 'Mois de la chronologie'
    },
    'recurrenceeditor': {
      'none': 'Aucun',
      'daily': 'du quotidien',
      'weekly': 'Hebdomadaire',
      'monthly': 'Mensuel',
      'month': 'Mois',
      'yearly': 'Annuel',
      'never': 'Jamais',
      'until': 'Jusqu\'à ce que',
      'count': 'Compter',
      'first': 'Premier',
      'second': 'Seconde',
      'third': 'Troisième',
      'fourth': 'Quatrième',
      'last': 'Dernier',
      'repeat': 'Répéter',
      'repeatEvery': 'Répéter tous les',
      'on': 'Répéter le',
      'end': 'Fin',
      'onDay': 'journée',
      'days': 'Journées)',
      'weeks': 'Semaines)',
      'months': 'Mois)',
      'years': 'Années)',
      'every': 'chaque',
      'summaryTimes': 'fois)',
      'summaryOn': 'sur',
      'summaryUntil': 'jusqu\'à ce que',
      'summaryRepeat': 'Répétitions',
      'summaryDay': 'journées)',
      'summaryWeek': 'semaines)',
      'summaryMonth': 'mois)',
      'summaryYear': 'années)',
      'monthWeek': 'Mois Semaine',
      'monthPosition': 'Position du mois',
      'monthExpander': 'Mois Expander',
      'yearExpander': 'Année Expander',
      'repeatInterval': 'Intervalle de répétition'
    },
    'calendar': {
      'today': 'Aujourd\'hui'
    }
  }
});
@Component({
  selector: 'app-planning',
  templateUrl: './planning.component.html',
  styleUrls: ['./planning.component.css'],
  encapsulation: ViewEncapsulation.None,
  providers: [DayService, WeekService, WorkWeekService, MonthService, AgendaService, ResizeService, DragAndDropService]
})
export class PlanningComponent implements OnInit {
  context = 'Temps Passés';
  subContext = 'Planning';

  private dialog: MatDialog;

  @ViewChild('scheduleObj')
  public scheduleObj: ScheduleComponent;
  public selectedDate: Date = new Date();

  public showWeekend: Boolean = false;
  public timeScale: TimeScaleModel = { enable: false, interval: 60, slotCount: 6 };
  public allowMultiple: Boolean = true;
  public rowAutoHeight: Boolean = true;
  public showQuickInfo: Boolean = false;
  public height = MAXHEIGHT;

  public group: GroupModel = {
    resources: ['Personnel', 'Matériel']
  };

  public projectDataSource: Object[] = [
    { text: 'Personnel', id: 1, color: '#cb6bb2' },
    { text: 'Matériel', id: 2, color: '#56ca85' }
  ];
  public categoryDataSource: Object[] = [
    { text: 'Romaine Carpentier', id: 1, groupId: 1, color: '#df5286' },
    { text: 'Ludovic Choquet', id: 2, groupId: 1, color: '#7fa900' },
    { text: 'Bruno Desmarais', id: 3, groupId: 1, color: '#ea7a57' },
    { text: 'Kangoo', id: 4, groupId: 2, color: '#5978ee' },
    { text: 'Combo', id: 5, groupId: 2, color: '#df5286' },
    { text: 'Citan', id: 6, groupId: 2, color: '#00bdae' }
  ];

  public resourceData: Object[] = [];

  public timelineResourceData: Object[] = [];

  public eventSettings: EventSettingsModel = {
    dataSource: <Object[]>extend([], this.resourceData.concat(this.timelineResourceData), null, true)
  };

  onCellClick(args): void {
    args.cancel = true;
    args.isAllDay = false;

    const dialogConfig: MatDialogConfig<any> = new MatDialogConfig<any>();
    dialogConfig.disableClose = true;
    dialogConfig.width = 'auto';
    let dialogRef = null;
    dialogConfig.data = {
      startTime: args.startTime,
      endTime: args.endTime
    };
    // dialogRef = this.dialog.open(, dialogConfig);
  }

  constructor() {
  }

  ngOnInit(): void {
    setCulture("fr-CH");
  }

}
